## Quick Start Guide

To get started quickly locally, you will need at least Python 3.10.6 installed.  If using Windows, we recommend installing [Windows Subsystem For Linux](https://learn.microsoft.com/en-us/windows/wsl/install) first.

Open a terminal and run the following commands:

```
git clone https://github.com/Josh-XT/AGiXT
cd AGiXT
./AGiXT.sh
```

Follow the prompts to install the required dependencies.  Any time you want to run AGiXT in the future, just run `./AGiXT.sh` again.

- Access the web interface at http://localhost:8501
- Access the AGiXT API documentation at http://localhost:7437
